<?php

namespace Drupal\notification_system_database\Form;

use Drupal\Core\Entity\ContentEntityForm;
use Drupal\Core\Form\FormStateInterface;

/**
 * Form controller for the notification entity edit forms.
 */
class NotificationForm extends ContentEntityForm {

  /**
   * {@inheritdoc}
   */
  public function save(array $form, FormStateInterface $form_state) {

    $entity = $this->getEntity();
    $result = $entity->save();
    $link = $entity->toLink($this->t('View'))->toRenderable();

    $message_arguments = ['%label' => $this->entity->label()];
    $logger_arguments = $message_arguments + ['link' => \Drupal::service('renderer')->render($link)];

    if ($result == SAVED_NEW) {
      $this->messenger()->addStatus($this->t('New notification %label has been created.', $message_arguments));
      $this->logger('notification_system_database')->notice('Created new notification %label', $logger_arguments);
    }
    else {
      $this->messenger()->addStatus($this->t('The notification %label has been updated.', $message_arguments));
      $this->logger('notification_system_database')->notice('Updated new notification %label.', $logger_arguments);
    }

    $form_state->setRedirect('entity.notification.canonical', ['notification' => $entity->id()]);
  }

}
